@@ -32,7 +32,6 @@
 # define VTKTESTINGIOSQL_NO_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkIOSQLModule.h"
+
 
 #endif
