@@ -16,8 +16,7 @@ import java.io.File;
  */
 public enum vtkNativeLibrary {
 
-    VTKACCELERATORSDAX("vtkAcceleratorsDaxJava", false),
-    VTKACCELERATORSPISTON("vtkAcceleratorsPistonJava", false),
+    VTKACCELERATORSVTKM("vtkAcceleratorsVTKmJava", false),
     VTKCHARTSCORE("vtkChartsCoreJava", true),
     VTKCOMMONCOLOR("vtkCommonColorJava", true),
     VTKCOMMONCOMPUTATIONALGEOMETRY("vtkCommonComputationalGeometryJava", true),
@@ -29,7 +28,8 @@ public enum vtkNativeLibrary {
     VTKCOMMONSYSTEM("vtkCommonSystemJava", true),
     VTKCOMMONTRANSFORMS("vtkCommonTransformsJava", true),
     VTKDOMAINSCHEMISTRY("vtkDomainsChemistryJava", true),
-    VTKDOMAINSCHEMISTRYOPENGL2("vtkDomainsChemistryOpenGL2Java", false),
+    VTKDOMAINSCHEMISTRYOPENGL2("vtkDomainsChemistryOpenGL2Java", true),
+    VTKDOMAINSMICROSCOPY("vtkDomainsMicroscopyJava", false),
     VTKFILTERSAMR("vtkFiltersAMRJava", true),
     VTKFILTERSCORE("vtkFiltersCoreJava", true),
     VTKFILTERSEXTRACTION("vtkFiltersExtractionJava", true),
@@ -41,12 +41,16 @@ public enum vtkNativeLibrary {
     VTKFILTERSHYPERTREE("vtkFiltersHyperTreeJava", true),
     VTKFILTERSIMAGING("vtkFiltersImagingJava", true),
     VTKFILTERSMODELING("vtkFiltersModelingJava", true),
+    VTKFILTERSOPENTURNS("vtkFiltersOpenTurnsJava", false),
     VTKFILTERSPARALLEL("vtkFiltersParallelJava", true),
+    VTKFILTERSPARALLELDIY2("vtkFiltersParallelDIY2Java", true),
     VTKFILTERSPARALLELFLOWPATHS("vtkFiltersParallelFlowPathsJava", true),
     VTKFILTERSPARALLELGEOMETRY("vtkFiltersParallelGeometryJava", true),
     VTKFILTERSPARALLELIMAGING("vtkFiltersParallelImagingJava", true),
     VTKFILTERSPARALLELMPI("vtkFiltersParallelMPIJava", true),
     VTKFILTERSPARALLELSTATISTICS("vtkFiltersParallelStatisticsJava", true),
+    VTKFILTERSPARALLELVERDICT("vtkFiltersParallelVerdictJava", true),
+    VTKFILTERSPOINTS("vtkFiltersPointsJava", true),
     VTKFILTERSPROGRAMMABLE("vtkFiltersProgrammableJava", true),
     VTKFILTERSPYTHON("vtkFiltersPythonJava", true),
     VTKFILTERSREEBGRAPH("vtkFiltersReebGraphJava", true),
@@ -54,8 +58,8 @@ public enum vtkNativeLibrary {
     VTKFILTERSSELECTION("vtkFiltersSelectionJava", true),
     VTKFILTERSSOURCES("vtkFiltersSourcesJava", true),
     VTKFILTERSSTATISTICS("vtkFiltersStatisticsJava", true),
-    VTKFILTERSSTATISTICSGNUR("vtkFiltersStatisticsGnuRJava", false),
     VTKFILTERSTEXTURE("vtkFiltersTextureJava", true),
+    VTKFILTERSTOPOLOGY("vtkFiltersTopologyJava", true),
     VTKFILTERSVERDICT("vtkFiltersVerdictJava", true),
     VTKGEOVISCORE("vtkGeovisCoreJava", true),
     VTKIOADIOS("vtkIOADIOSJava", false),
@@ -64,6 +68,8 @@ public enum vtkNativeLibrary {
     VTKIOENSIGHT("vtkIOEnSightJava", true),
     VTKIOEXODUS("vtkIOExodusJava", true),
     VTKIOEXPORT("vtkIOExportJava", true),
+    VTKIOEXPORTOPENGL("vtkIOExportOpenGLJava", false),
+    VTKIOEXPORTOPENGL2("vtkIOExportOpenGL2Java", true),
     VTKIOFFMPEG("vtkIOFFMPEGJava", true),
     VTKIOGDAL("vtkIOGDALJava", true),
     VTKIOGEOJSON("vtkIOGeoJSONJava", true),
@@ -71,6 +77,7 @@ public enum vtkNativeLibrary {
     VTKIOIMAGE("vtkIOImageJava", true),
     VTKIOIMPORT("vtkIOImportJava", true),
     VTKIOINFOVIS("vtkIOInfovisJava", true),
+    VTKIOLAS("vtkIOLASJava", false),
     VTKIOLSDYNA("vtkIOLSDynaJava", true),
     VTKIOLEGACY("vtkIOLegacyJava", true),
     VTKIOMINC("vtkIOMINCJava", true),
@@ -80,14 +87,19 @@ public enum vtkNativeLibrary {
     VTKIOMYSQL("vtkIOMySQLJava", true),
     VTKIONETCDF("vtkIONetCDFJava", true),
     VTKIOODBC("vtkIOODBCJava", true),
+    VTKIOPDAL("vtkIOPDALJava", false),
     VTKIOPLY("vtkIOPLYJava", true),
     VTKIOPARALLEL("vtkIOParallelJava", true),
     VTKIOPARALLELEXODUS("vtkIOParallelExodusJava", true),
     VTKIOPARALLELLSDYNA("vtkIOParallelLSDynaJava", true),
     VTKIOPARALLELNETCDF("vtkIOParallelNetCDFJava", true),
     VTKIOPARALLELXML("vtkIOParallelXMLJava", true),
+    VTKIOPARALLELXDMF3("vtkIOParallelXdmf3Java", true),
     VTKIOPOSTGRESQL("vtkIOPostgreSQLJava", true),
     VTKIOSQL("vtkIOSQLJava", true),
+    VTKIOSEGY("vtkIOSegYJava", true),
+    VTKIOTRUCHAS("vtkIOTRUCHASJava", true),
+    VTKIOTECPLOTTABLE("vtkIOTecplotTableJava", true),
     VTKIOVPIC("vtkIOVPICJava", true),
     VTKIOVIDEO("vtkIOVideoJava", true),
     VTKIOXML("vtkIOXMLJava", true),
@@ -101,13 +113,13 @@ public enum vtkNativeLibrary {
     VTKIMAGINGHYBRID("vtkImagingHybridJava", true),
     VTKIMAGINGMATH("vtkImagingMathJava", true),
     VTKIMAGINGMORPHOLOGICAL("vtkImagingMorphologicalJava", true),
+    VTKIMAGINGOPENGL2("vtkImagingOpenGL2Java", false),
     VTKIMAGINGSOURCES("vtkImagingSourcesJava", true),
     VTKIMAGINGSTATISTICS("vtkImagingStatisticsJava", true),
     VTKIMAGINGSTENCIL("vtkImagingStencilJava", true),
     VTKINFOVISBOOSTGRAPHALGORITHMS("vtkInfovisBoostGraphAlgorithmsJava", true),
     VTKINFOVISCORE("vtkInfovisCoreJava", true),
     VTKINFOVISLAYOUT("vtkInfovisLayoutJava", true),
-    VTKINFOVISPARALLEL("vtkInfovisParallelJava", false),
     VTKINTERACTIONIMAGE("vtkInteractionImageJava", true),
     VTKINTERACTIONSTYLE("vtkInteractionStyleJava", true),
     VTKINTERACTIONWIDGETS("vtkInteractionWidgetsJava", true),
@@ -116,27 +128,33 @@ public enum vtkNativeLibrary {
     VTKPARALLELMPI4PY("vtkParallelMPI4PyJava", true),
     VTKRENDERINGANNOTATION("vtkRenderingAnnotationJava", true),
     VTKRENDERINGCONTEXT2D("vtkRenderingContext2DJava", true),
-    VTKRENDERINGCONTEXTOPENGL("vtkRenderingContextOpenGLJava", true),
-    VTKRENDERINGCONTEXTOPENGL2("vtkRenderingContextOpenGL2Java", false),
+    VTKRENDERINGCONTEXTOPENGL("vtkRenderingContextOpenGLJava", false),
+    VTKRENDERINGCONTEXTOPENGL2("vtkRenderingContextOpenGL2Java", true),
     VTKRENDERINGCORE("vtkRenderingCoreJava", true),
     VTKRENDERINGEXTERNAL("vtkRenderingExternalJava", false),
     VTKRENDERINGFREETYPE("vtkRenderingFreeTypeJava", true),
-    VTKRENDERINGGL2PS("vtkRenderingGL2PSJava", true),
+    VTKRENDERINGGL2PS("vtkRenderingGL2PSJava", false),
+    VTKRENDERINGGL2PSOPENGL2("vtkRenderingGL2PSOpenGL2Java", true),
     VTKRENDERINGIMAGE("vtkRenderingImageJava", true),
-    VTKRENDERINGLIC("vtkRenderingLICJava", true),
-    VTKRENDERINGLICOPENGL2("vtkRenderingLICOpenGL2Java", false),
+    VTKRENDERINGLIC("vtkRenderingLICJava", false),
+    VTKRENDERINGLICOPENGL2("vtkRenderingLICOpenGL2Java", true),
     VTKRENDERINGLOD("vtkRenderingLODJava", true),
     VTKRENDERINGLABEL("vtkRenderingLabelJava", true),
     VTKRENDERINGMATPLOTLIB("vtkRenderingMatplotlibJava", true),
-    VTKRENDERINGOPENGL("vtkRenderingOpenGLJava", true),
-    VTKRENDERINGOPENGL2("vtkRenderingOpenGL2Java", false),
+    VTKRENDERINGOSPRAY("vtkRenderingOSPRayJava", false),
+    VTKRENDERINGOCULUS("vtkRenderingOculusJava", false),
+    VTKRENDERINGOPENGL("vtkRenderingOpenGLJava", false),
+    VTKRENDERINGOPENGL2("vtkRenderingOpenGL2Java", true),
+    VTKRENDERINGOPENVR("vtkRenderingOpenVRJava", false),
+    VTKRENDERINGOPTIX("vtkRenderingOptiXJava", false),
     VTKRENDERINGPARALLEL("vtkRenderingParallelJava", true),
     VTKRENDERINGPARALLELLIC("vtkRenderingParallelLICJava", true),
     VTKRENDERINGQT("vtkRenderingQtJava", true),
+    VTKRENDERINGSCENEGRAPH("vtkRenderingSceneGraphJava", true),
     VTKRENDERINGVOLUME("vtkRenderingVolumeJava", true),
     VTKRENDERINGVOLUMEAMR("vtkRenderingVolumeAMRJava", true),
-    VTKRENDERINGVOLUMEOPENGL("vtkRenderingVolumeOpenGLJava", true),
-    VTKRENDERINGVOLUMEOPENGL2("vtkRenderingVolumeOpenGL2Java", false),
+    VTKRENDERINGVOLUMEOPENGL("vtkRenderingVolumeOpenGLJava", false),
+    VTKRENDERINGVOLUMEOPENGL2("vtkRenderingVolumeOpenGL2Java", true),
     VTKTESTINGRENDERING("vtkTestingRenderingJava", true),
     VTKPYTHONINTERPRETER("vtkPythonInterpreterJava", true),
     VTKVIEWSCONTEXT2D("vtkViewsContext2DJava", true),
